EXPORTS
	??1CCameraSnapshot@CCamera@@UAE@XZ @ 1 NONAME ; CCamera::CCameraSnapshot::~CCameraSnapshot(void)
	?IsSnapshotActive@CCameraSnapshot@CCamera@@QBEHXZ @ 2 NONAME ; int CCamera::CCameraSnapshot::IsSnapshotActive(void) const
	?NewL@CCameraSnapshot@CCamera@@SAPAV12@AAV2@@Z @ 3 NONAME ; class CCamera::CCameraSnapshot * CCamera::CCameraSnapshot::NewL(class CCamera &)
	?PrepareSnapshotL@CCameraSnapshot@CCamera@@QAEXW4TFormat@2@ABVTPoint@@ABVTSize@@ABVTRgb@@H@Z @ 4 NONAME ; void CCamera::CCameraSnapshot::PrepareSnapshotL(enum CCamera::TFormat, class TPoint const &, class TSize const &, class TRgb const &, int)
	?PrepareSnapshotL@CCameraSnapshot@CCamera@@QAEXW4TFormat@2@ABVTSize@@H@Z @ 5 NONAME ; void CCamera::CCameraSnapshot::PrepareSnapshotL(enum CCamera::TFormat, class TSize const &, int)
	?SetBgColorL@CCameraSnapshot@CCamera@@QAEXABVTRgb@@@Z @ 6 NONAME ; void CCamera::CCameraSnapshot::SetBgColorL(class TRgb const &)
	?SetPositionL@CCameraSnapshot@CCamera@@QAEXABVTPoint@@@Z @ 7 NONAME ; void CCamera::CCameraSnapshot::SetPositionL(class TPoint const &)
	?SnapshotDataL@CCameraSnapshot@CCamera@@QAEAAVMCameraBuffer@@AAV?$RArray@H@@@Z @ 8 NONAME ; class MCameraBuffer & CCamera::CCameraSnapshot::SnapshotDataL(class RArray<int> &)
	?StartSnapshot@CCameraSnapshot@CCamera@@QAEXXZ @ 9 NONAME ; void CCamera::CCameraSnapshot::StartSnapshot(void)
	?StopSnapshot@CCameraSnapshot@CCamera@@QAEXXZ @ 10 NONAME ; void CCamera::CCameraSnapshot::StopSnapshot(void)
	?SupportedFormats@CCameraSnapshot@CCamera@@QAEKXZ @ 11 NONAME ; unsigned long CCamera::CCameraSnapshot::SupportedFormats(void)
	??0TSnapshotParameters@CCameraSnapshot@CCamera@@QAE@XZ @ 12 NONAME ; CCamera::CCameraSnapshot::TSnapshotParameters::TSnapshotParameters(void)
	?CreateHistogramHandleL@CCameraSnapshot@CCamera@@QBEPAVCCameraV2Histogram@2@XZ @ 13 NONAME ; class CCamera::CCameraV2Histogram * CCamera::CCameraSnapshot::CreateHistogramHandleL(void) const
	?CreateL@CCameraSnapshot@CCamera@@CAPAV12@AAV2@AAVMImplementationFactory@@@Z @ 14 NONAME ABSENT
	?DisableSnapshotL@CCameraSnapshot@CCamera@@QAEXXZ @ 15 NONAME ; void CCamera::CCameraSnapshot::DisableSnapshotL(void)
	?EnableSnapshotL@CCameraSnapshot@CCamera@@QAEXXZ @ 16 NONAME ; void CCamera::CCameraSnapshot::EnableSnapshotL(void)
	?GetSnapshotParametersL@CCameraSnapshot@CCamera@@QAEXAAVTSnapshotParameters@12@@Z @ 17 NONAME ; void CCamera::CCameraSnapshot::GetSnapshotParametersL(class CCamera::CCameraSnapshot::TSnapshotParameters &)
	?GetSnapshotStatusL@CCameraSnapshot@CCamera@@QBEXAAW4TSnapshotState@12@@Z @ 18 NONAME ; void CCamera::CCameraSnapshot::GetSnapshotStatusL(enum CCamera::CCameraSnapshot::TSnapshotState &) const
	?IsAspectRatioMaintained@TSnapshotParameters@CCameraSnapshot@CCamera@@QBEHXZ @ 19 NONAME ; int CCamera::CCameraSnapshot::TSnapshotParameters::IsAspectRatioMaintained(void) const
	?IsClientSnapshotUsed@TSnapshotParameters@CCameraSnapshot@CCamera@@QBEHXZ @ 20 NONAME ABSENT
	?PrepareSnapshotL@CCameraSnapshot@CCamera@@QAEXABVTSnapshotParameters@12@@Z @ 21 NONAME ; void CCamera::CCameraSnapshot::PrepareSnapshotL(class CCamera::CCameraSnapshot::TSnapshotParameters const &)
	?SelectSnapshotVideoFramesL@CCameraSnapshot@CCamera@@QAEXW4TSnapshotVideoFrames@12@@Z @ 22 NONAME ; void CCamera::CCameraSnapshot::SelectSnapshotVideoFramesL(enum CCamera::CCameraSnapshot::TSnapshotVideoFrames)
	?SetAspectRatioState@TSnapshotParameters@CCameraSnapshot@CCamera@@QAEXH@Z @ 23 NONAME ; void CCamera::CCameraSnapshot::TSnapshotParameters::SetAspectRatioState(int)
	?SetClientSnapshotState@TSnapshotParameters@CCameraSnapshot@CCamera@@QAEXH@Z @ 24 NONAME ABSENT
	?SetSnapshotParametersL@CCameraSnapshot@CCamera@@QAEXABVTSnapshotParameters@12@@Z @ 25 NONAME ; void CCamera::CCameraSnapshot::SetSnapshotParametersL(class CCamera::CCameraSnapshot::TSnapshotParameters const &)
	?Size@TSnapshotParameters@CCameraSnapshot@CCamera@@QBEIXZ @ 26 NONAME ; unsigned int CCamera::CCameraSnapshot::TSnapshotParameters::Size(void) const
	?Version@TSnapshotParameters@CCameraSnapshot@CCamera@@QBEIXZ @ 27 NONAME ; unsigned int CCamera::CCameraSnapshot::TSnapshotParameters::Version(void) const
	?CreateL@CCameraSnapshot@CCamera@@CAPAV12@AAV2@AAVMImplementationFactory@@H@Z @ 28 NONAME ; class CCamera::CCameraSnapshot * CCamera::CCameraSnapshot::CreateL(class CCamera &, class MImplementationFactory &, int)

